@@ -3,22 +3,36 @@ NULL
 
 #' Check reporter: 13 line summary of problems
 #'
-#' \code{R CMD check} displays only the last 13 lines of the result, so this
+#' `R CMD check` displays only the last 13 lines of the result, so this
 #' report is design to ensure that you see something useful there.
 #'
 #' @export
-CheckReporter <- R6::R6Class("CheckReporter", inherit = Reporter,
+#' @family reporters
+CheckReporter <- R6::R6Class("CheckReporter",
+  inherit = Reporter,
   public = list(
     failures = list(),
     n_ok = 0L,
     n_skip = 0L,
     n_fail = 0L,
+    n_warn = 0L,
+
+    stop_on_failure = TRUE,
+
+    initialize = function(stop_on_failure = TRUE, ...) {
+      self$stop_on_failure <- stop_on_failure
+      super$initialize(...)
+    },
 
     add_result = function(context, test, result) {
       if (expectation_skip(result)) {
         self$n_skip <- self$n_skip + 1L
         return()
       }
+      if (expectation_warning(result)) {
+        self$n_warn <- self$n_warn + 1L
+        return()
+      }
       if (expectation_ok(result)) {
         self$n_ok <- self$n_ok + 1L
         return()
@@ -27,15 +41,16 @@ CheckReporter <- R6::R6Class("CheckReporter", inherit = Reporter,
       self$n_fail <- self$n_fail + 1L
       self$failures[[self$n_fail]] <- result
 
-      self$cat_paragraph(failure_summary(result, self$n_fail))
+      self$cat_line(failure_summary(result, self$n_fail))
+      self$cat_line()
     },
 
     end_reporter = function() {
-      rule <- paste0(rep("=", getOption("width") - 16), collapse = "")
-      self$cat_line("testthat results ", rule)
+      self$rule("testthat results ", line = 2)
       self$cat_line(
         "OK: ", self$n_ok, " ",
         "SKIPPED: ", self$n_skip, " ",
+        "WARNINGS: ", self$n_warn, " ",
         "FAILED: ", self$n_fail
       )
 
@@ -52,13 +67,17 @@ CheckReporter <- R6::R6Class("CheckReporter", inherit = Reporter,
         fails <- c(fails, "...")
       }
       labels <- format(paste0(1:length(show), "."))
-      self$cat_paragraph(paste0(labels, " ", fails, collapse = "\n"))
+      self$cat_line(paste0(labels, " ", fails, collapse = "\n"))
+      self$cat_line()
 
-      stop("testthat unit tests failed", call. = FALSE)
+      if (self$stop_on_failure) {
+        stop("testthat unit tests failed", call. = FALSE)
+      }
     }
   )
 )
 
+
 skip_summary <- function(x, label) {
   header <- paste0(label, ". ", x$test)
 
@@ -67,13 +86,11 @@ skip_summary <- function(x, label) {
   )
 }
 
-failure_summary <- function(x, label, width = getOption("width")) {
+failure_summary <- function(x, label, width = cli::console_width()) {
   header <- paste0(label, ". ", failure_header(x))
-  linewidth <- ifelse(nchar(header) > width, 0, width - nchar(header))
-  line <- paste(rep("-", linewidth), collapse = "")
 
   paste0(
-    colourise(header, "error"), line, "\n",
+    cli::rule(header, col = testthat_style("error")), "\n",
     format(x)
   )
 }
