@@ -1,3 +1,7 @@
+test_that("Success", {
+  succeed()
+})
+
 context("Expectations")
 
 test_that("Success", {
@@ -21,6 +25,7 @@ test_that("Failure:loop", {
   }
 })
 
+context("Expectations2")
 
 context("Errors")
 
@@ -29,13 +34,28 @@ test_that("Error:1", {
 })
 
 test_that("Error:3", {
-  f <- function() {g()}
-  g <- function() {h()}
-  h <- function() {stop("!")}
+  f <- function() {
+    g()
+  }
+  g <- function() {
+    h()
+  }
+  h <- function() {
+    stop("!")
+  }
 
   f()
 })
 
+context("Recursion")
+
+test_that("Recursion:1", {
+  f <- function(x) {
+    if (x > 0) f(x - 1) else stop("This is deep")
+  }
+  f(25)
+})
+
 context("Skips")
 
 test_that("Skip:1", {
@@ -43,19 +63,26 @@ test_that("Skip:1", {
 })
 
 test_that("Skip:2", {
-  f <- function() {skip("skip")}
+  f <- function() {
+    skip("skip")
+  }
   f()
 })
 
+test_that("Skip:3", {
+})
+
 context("Warnings")
 
 test_that("Warning:1", {
   warning("abc")
 })
-
 test_that("Warning:2", {
+  f <- function() {
+    warning("ghi")
+  }
   warning("def")
-  warning("ghi")
+  f()
 })
 
 context("Output")
@@ -63,3 +90,5 @@ context("Output")
 test_that("Output:1", {
   expect_output(expect_false(FALSE), NA)
 })
+
+context("End")
